@@ -1,4 +1,4 @@
-__version__ = "1.0.4"
+__version__ = "1.0.6"
 
 from .resolvers.default_resolver import DefaultResolver
 from .resolvers.resolver import Resolver
@@ -6,4 +6,5 @@ from .resolvers.scalar_resolvers.scalar_resolver import ScalarResolver
 from .resolvers.collection_resolvers.collection_resolver import CollectionResolver
 from .resolvers.post_processors.post_processor import PostProcessor
 
-from .functional.load import from_string, from_file_uri
\ No newline at end of file
+from .functional.load import from_string, from_file_uri, from_cli, from_primitive
+from .functional.util import merge, mask_in, mask_out
\ No newline at end of file
